<?php
/*
* Testimonial Custom Post type
*/
if ( ! class_exists( 'Testimonial_Post_Type' ) )
{
	class Testimonial_Post_Type
	{
		function __construct()
		{
			/**
			* Create Testimonial CPT
			*
			* Function Name: testimonial_init
			*
			* @access public
			* 
			**/
			add_action( 'init', array( &$this, 'testimonial_init' ) );

			/**
			* Add Meta Box to Testimonial CPT
			*
			* Function Name: testimonial_meta_box_add
			*
			* @access public
			*
			**/
            add_action( 'add_meta_boxes', array( &$this, 'testimonial_meta_box_add' ) );
            
            /**
			* Save data from meta box
			*
			* Function Name: testimonial_metabox_save
			*
			* @access public
			* @param array  $testimonial_box : Holds parameters to be passed to add_meta_box function 
			* @param int    $post_id : Contains ID of post.
			* @param int 	$old : Old values of inputs saved in database
			* @param int 	$new : New values of inputs to be updated in database
			* 
			*/
            add_action( 'save_post', array( &$this, 'testimonial_metabox_save' ) );
            
            /**
			* Updating messages 
			*
			* Function Name: testimonial_set_messages
			*
			* @access public
			* @param var  $message : Holds message to be displayed
			* 
			**/
            add_filter( 'post_updated_messages', array( &$this, 'testimonial_set_messages' ) );
            
            /**
			* Create company name & client location field in Testimonial post
			*
			* Function Name: add_thumbnail_column
			*
			* @access public
			* 
			**/
            add_filter( 'manage_edit-testimonials_columns', array( &$this, 'add_thumbnail_column'), 10, 1 );
			add_action( 'manage_testimonials_posts_custom_column', array( &$this, 'display_thumbnail' ), 10, 1 );
			add_filter( 'enter_title_here',array( &$this, 'testimonial_default_title' ));
            
            /**
			* Rename Featured image title text
			*
			* Function Name: client_testimonial_change_image_box
			*
			* @access public
			* 
			**/
			add_action( 'do_meta_boxes', array( &$this,'client_testimonial_change_image_box' ) );
			
            global $testimonial_box;
			$prefix = 'testimonial_';
			$testimonial_box = array(
			    'id' => 'testimonialid',
			    'title' => 'Testimonial Information',
				'page' => 'testimonials',
			    'context' => 'normal',
			    'priority' => 'low',
			    'fields' => array(
					array(
			            'name' => 'Name',
			            'desc' => 'Enter name.',
			            'id' => $prefix . 'name',
			            'type' => 'text',
			            'std' => ''
			        ),
			        array(
			            'name' => 'Company Name',
			            'desc' => 'Enter company name.',
			            'id' => $prefix . 'company_name',
			            'type' => 'text',
			            'std' => ''
			        ),
					array(
			            'name' => 'Company Url',
			            'desc' => 'Specify URL.',
			            'id' => $prefix . 'company_url',
			            'type' => 'text',
			            'std' => ''
			        )
				)
			);
		}
		
		/**
		* Create Testimonial CPT
		*
		* Function Name: testimonial_init
		*
		* @access public
		* 
		**/
		function testimonial_init()
		{

			$labels_testimonial = array(
								'name' 					=> __('Testimonials','dts'),
								'singular_name' 		=> __('Testimonials','dts'),
								'add_new' 				=> __('Add Testimonial','dts'),
								'add_new_item' 			=> __('Add New Testimonial','dts'),
								'edit_item' 			=> __('Edit Testimonial','dts'),
								'new_item' 				=> __('New Testimonial','dts'),
								'all_items' 			=> __('All Testimonials','dts'),
								'search_items' 			=> __('Search Testimonials','dts'),
								'not_found' 			=> __('No Testimonials found','dts'),
								'not_found_in_trash' 	=> __('No Testimonials found in Trash','dts'), 
								'parent_item_colon'		=> '',
								'menu_name' 			=> __('Testimonials','dts')
							);
			$argstestimonial = array(
							'labels' 			=> $labels_testimonial,
							'public' 			=> true,
							'show_ui' 			=> true, 
							'rewrite' 			=> array( 'slug' => 'testimonials' ),
							'capability_type' 	=> 'post',
							'menu_icon' 		=> 'dashicons-editor-quote',
							'hierarchical' 		=> true,
							'supports' 			=> array( 'title', 'editor', 'thumbnail' ),
							'exclude_from_search' => false,
							'publicly_queryable' => true,
							'show_in_menu' => true,
							'show_in_nav_menus' =>true,
							'show_in_admin_bar' => true,
							'has_archive' => true,
							'query_var'             => true,
						);
        	  
        	 register_post_type( 'testimonials', $argstestimonial ); 
			 
			 // Add new taxonomy, NOT hierarchical (like tags)
			$labelscat_testimonial = array(
				'name'                       => __( 'Testimonial Category', 'dts' ),
				'singular_name'              => __( 'Testimonial Category',  'dts' ),
				'search_items'               => __( 'Search Testimonial Category', 'dts' ),
				'popular_items'              => __( 'Popular Testimonial Category', 'dts' ),
				'all_items'                  => __( 'All Testimonial Category', 'dts' ),
				'parent_item'                => null,
				'parent_item_colon'          => null,
				'edit_item'                  => __( 'Edit Testimonial Category', 'dts' ),
				'update_item'                => __( 'Update Testimonial Category', 'dts' ),
				'add_new_item'               => __( 'Add New Testimonial Category', 'dts' ),
				'new_item_name'              => __( 'New Testimonial Category Name', 'dts' ),
				'separate_items_with_commas' => __( 'Separate Testimonial Category with commas', 'dts' ),
				'add_or_remove_items'        => __( 'Add or remove Testimonial Category', 'dts' ),
				'choose_from_most_used'      => __( 'Choose from the most used Testimonial Category', 'dts' ),
				'not_found'                  => __( 'No Testimonial Category found.', 'dts' ),
				'menu_name'                  => __( 'Testimonial Category', 'dts' ),
			);
	
			 $args_cat_testimonial = array(
				'hierarchical'          => true,
				'labels'                => $labelscat_testimonial,
				'show_ui'               => true,
				'show_in_menu'          => true,
				'public'          => true,
				'publicly_queryable'          => true,
				'show_in_nav_menus'          => true,
				'show_in_quick_edit'          => true,
				'show_admin_column'     => true,
				'update_count_callback' => '_update_post_term_count',
				'query_var'             => true,
				'rewrite'               => array( 'slug' => 'b3m_testimonial_category' ),
			);
		
			register_taxonomy( 'b3m_testimonial_category', 'testimonials', $args_cat_testimonial );
			register_taxonomy_for_object_type( 'b3m_testimonial_category', 'testimonials' );
			flush_rewrite_rules();
        }
        
        /**
		* Add Meta Box to Testimonial CPT
		*
		* Function Name: testimonial_meta_box_add
		*
		* @access public
		*
		**/
        function testimonial_meta_box_add() 
		{
			global $testimonial_box;
				
		    add_meta_box( $testimonial_box['id'], $testimonial_box['title'], array( &$this, 'testimonial_meta_box_cb' ), 'testimonials', $testimonial_box['context'], $testimonial_box['priority'] );
		}
		
		/**
		* Callback Function of Testimonial Meta Box
		*
		* Function Name: testimonial_meta_box_cb
		*
		* @access public
		* 
		**/
		function testimonial_meta_box_cb()
		{
    		global $testimonial_box, $post;
	
			echo '<input type="hidden" name="testimonial_meta_box_nonce" value="', wp_create_nonce( basename(__FILE__) ), '" />';
			echo '<table class="form-table">';
			foreach ( $testimonial_box['fields'] as $field )
			{
		        // get current post meta data
		        $testimonial_check_value = get_post_meta( $post->ID, $field['id'], true );
		        echo '<tr class="form-field">',
		                '<th scope="row"><label for="', $field['id'], '">', _e($field['name'],'aiinfo'), '</label></th>',
		                '<td>';
		        switch ( $field['type'] )
		        {
		            case 'text':
		                echo '<input type="text" name="', $field['id'], '" id="', $field['id'], '" value="', $testimonial_check_value ? $testimonial_check_value : $field['std'], '" />', '<br />', $field['desc'];
		                break;
		             case 'checkbox':
		                echo '<input type="checkbox" name="', $field['id'], '" id="', $field['id'], '" '.checked($testimonial_check_value,"on" ).'/>', $field['desc'];
		                break;    
		            
		        }
		        echo  '</td><td>',
		            '</td></tr>';
		    }
			echo '</table>';
		}
		
		/**
		* Save data from meta box
		*
		* Function Name: testimonial_metabox_save
		*
		* @access public
		* @param array  $testimonial_box : Holds parameters to be passed to add_meta_box function 
		* @param int    $post_id : Contains ID of post.
		* @param int 	$old : Old values of inputs saved in database
		* @param int 	$new : New values of inputs to be updated in database
		* 
		*/
		function testimonial_metabox_save( $post_id )
		{
		    global $testimonial_box;

		    // verify nonce
		    if ( !wp_verify_nonce( $_POST['testimonial_meta_box_nonce'], basename(__FILE__) ) )
			{ 
		        return $post_id;
		    }

		    // check autosave
		    if ( defined('DOING_AUTOSAVE') && DOING_AUTOSAVE ) {
		        return $post_id;
		    }

		    // check permissions
		    if ( 'page' == $_POST['post_type'] ) {
		        if (!current_user_can('edit_page', $post_id)) { 
		            return $post_id;
		        }
		    } elseif (!current_user_can('edit_post', $post_id)) { 
		        return $post_id;
		    }

		    foreach ( $testimonial_box['fields'] as $field ) {
		        $old = get_post_meta( $post_id, $field['id'], true );
		        $new = $_POST[$field['id']];
		        if ( $new && $new != $old ) { 
		            update_post_meta( $post_id, $field['id'], $new );
		        } elseif ('' == $new && $old) {
		            delete_post_meta( $post_id, $field['id'], $old );
		        }
		    }
		}
		
		/**
		* Create company name & client location field in Testimonial post
		*
		* Function Name: add_thumbnail_column
		*
		* @access public
		* 
		**/
		function add_thumbnail_column( $columns )
		{
			unset($columns['wpex_post_thumbs']);

			$column_testimonial = array( 'company_name' => __('Company Name','testimonials' ));
			$columns = array_slice( $columns, 0, 1, true ) + array_slice( $columns, 1, 1, true ) + $column_testimonial + array_slice( $columns, 1, NULL, true );
			return $columns;
		}
		
		function display_thumbnail( $column )
		{
			global $post;
			
			switch ( $column ) {
				case 'company_name':
					echo  $company_name = get_post_meta($post->ID, 'testimonial_company_name', true);
					break;
				
			}
		}
		
		/**
		* Updating messages 
		*
		* Function Name: testimonial_set_messages
		*
		* @access public
		* @param var  $message : Holds message to be displayed
		* 
		**/
		function testimonial_set_messages($messages) {
			
			global $post, $post_ID;
			$post_type = get_post_type( $post_ID );

			$obj = get_post_type_object( $post_type );
			$singular = $obj->labels->singular_name;

			$messages[$post_type] = array(
			0 => '', // Unused. Messages start at index 1.
			1 => sprintf( __($singular.' updated. <a href="%s">View '.strtolower($singular).'</a>'), esc_url( get_permalink($post_ID) ) ),
			2 => __($singular .'Custom field updated.'),
			3 => __($singular.'Custom field deleted.'),
			4 => __($singular.' updated.'),
			5 => isset($_GET['revision']) ? sprintf( __($singular.' restored to revision from %s'), wp_post_revision_title( (int) $_GET['revision'], false ) ) : false,
			6 => sprintf( __($singular.' published. <a href="%s">View '.strtolower($singular).'</a>'), esc_url( get_permalink($post_ID) ) ),
			7 => __('Page saved.'),
			8 => sprintf( __($singular.' submitted. <a target="_blank" href="%s">Preview '.strtolower($singular).'</a>'), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
			9 => sprintf( __($singular.' scheduled for: <strong>%1$s</strong>. <a target="_blank" href="%2$s">Preview '.strtolower($singular).'</a>'), date_i18n( __( 'M j, Y @ G:i' ), strtotime( $post->post_date ) ), esc_url( get_permalink($post_ID) ) ),
			10 => sprintf( __($singular.' draft updated. <a target="_blank" href="%s">Preview '.strtolower($singular).'</a>'), esc_url( add_query_arg( 'preview', 'true', get_permalink($post_ID) ) ) ),
			);
			return $messages;
		}
		
		/**
		* Rename Featured image title text
		*
		* Function Name: client_testimonial_change_image_box
		*
		* @access public
		* 
		**/
		function client_testimonial_change_image_box()
		{
			remove_meta_box( 'postimagediv', 'testimonials', 'side' );
    		add_meta_box( 'postimagediv', __('Client Image (150px * 150px)'), 'post_thumbnail_meta_box', 'testimonials', 'side', 'low' );
		}
		
		function testimonial_default_title( $title ){
			$screen = get_current_screen();
			if ( 'testimonials' == $screen->post_type ){
				$title = 'Enter the name';
			}
			return $title;
		}

		
	}
	new Testimonial_Post_Type;
}
?>